.. mdinclude:: readme.rst

.. toctree::
   :hidden:
   :maxdepth: 2

   Overview <readme>
   installation
   usage

.. toctree::
   :caption: Advanced Usage
   :hidden:

   API Reference <api/ballet>

.. toctree::
   :caption: Development Notes
   :hidden:

   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
